@@ -31,6 +31,11 @@
 #include <gtk/gtk.h>
 #include <gtk/gtkbutton.h>
 
+#ifdef G_OS_WIN32
+/* Clashes with objidl.h, which gets included through a chain of includes from libsoup/soup.h */
+#undef DATADIR			
+#endif
+
 #include <libsoup/soup.h>
 #include <sys/stat.h>
 #include <fcntl.h>
@@ -89,13 +94,7 @@ static void on_set_base (GtkHTML *html, const gchar *url, gpointer data);
 
 static gchar *parse_href (const gchar *s);
 
-#ifdef HAVE_OLD_SOUP
-#define SOUP_STATUS_IS_SUCCESSFUL SOUP_ERROR_IS_SUCCESSFUL
-#define status_code errorcode
-#define reason_phrase errorphrase
-#else
 static SoupSession *session;
-#endif
 
 static GtkHTML *html;
 static GtkHTMLStream *html_stream_handle = NULL;
@@ -104,7 +103,6 @@ static GtkWidget *entry;
 static GtkWidget *popup_menu, *popup_menu_back, *popup_menu_forward, *popup_menu_home;
 static GtkWidget *toolbar_back, *toolbar_forward;
 static HTMLURL *baseURL = NULL;
-static GtkTooltips *tooltips;
 
 static GList *go_list;
 static int go_position;
@@ -207,14 +205,14 @@ create_toolbars (GtkWidget *app)
 	gtk_box_pack_start (GTK_BOX (hbox), toolbar, FALSE, FALSE, 0);
 
 	item = gtk_tool_button_new_from_stock (GTK_STOCK_GO_BACK);
-	gtk_tool_item_set_tooltip (item, tooltips, "Move back", "Back");
+	gtk_tool_item_set_tooltip_text (item, "Move back");
 	g_signal_connect (item, "clicked", G_CALLBACK (back_cb), NULL);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
 	gtk_widget_set_sensitive (GTK_WIDGET (item), FALSE);
 	toolbar_back = GTK_WIDGET (item);
 
 	item = gtk_tool_button_new_from_stock (GTK_STOCK_GO_FORWARD);
-	gtk_tool_item_set_tooltip (item, tooltips, "Move forward", "Forward");
+	gtk_tool_item_set_tooltip_text (item, "Move forward");
 	g_signal_connect (item, "clicked", G_CALLBACK (forward_cb), NULL);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
 	gtk_widget_set_sensitive (GTK_WIDGET (item), FALSE);
@@ -224,17 +222,17 @@ create_toolbars (GtkWidget *app)
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
 
 	item = gtk_tool_button_new_from_stock (GTK_STOCK_STOP);
-	gtk_tool_item_set_tooltip (item, tooltips, "Stop loading", "Stop");
+	gtk_tool_item_set_tooltip_text (item, "Stop loading");
 	g_signal_connect (item, "clicked", G_CALLBACK (stop_cb), NULL);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
 
 	item = gtk_tool_button_new_from_stock (GTK_STOCK_REFRESH);
-	gtk_tool_item_set_tooltip (item, tooltips, "Reload page", "Reload");
+	gtk_tool_item_set_tooltip_text (item, "Reload page");
 	g_signal_connect (item, "clicked", G_CALLBACK (reload_cb), NULL);
 	gtk_toolbar_insert (GTK_TOOLBAR (toolbar), item, -1);
 
 	item = gtk_tool_button_new_from_stock (GTK_STOCK_HOME);
-	gtk_tool_item_set_tooltip (item, tooltips, "Home page", "Home");
+	gtk_tool_item_set_tooltip_text (item, "Home page");
 	g_signal_connect (item, "clicked", G_CALLBACK (home_cb), NULL);
 
 	item = gtk_separator_tool_item_new ();
@@ -517,11 +515,7 @@ static void
 stop_cb (GtkWidget *widget, gpointer data)
 {
 	/* Kill all requests */
-#ifdef HAVE_OLD_SOUP
-	soup_shutdown ();
-#else
 	soup_session_abort (session);
-#endif
 	html_stream_handle = NULL;
 }
 
@@ -647,7 +641,7 @@ object_timeout(GtkHTMLEmbedded *eb)
 	printf("inserting custom widget after a delay ...\n");
 	gtk_html_embedded_set_descent(eb, rand()%8);
 	gtk_container_add (GTK_CONTAINER(eb), w);
-	gtk_widget_unref (GTK_WIDGET (eb));
+	g_object_unref (eb);
 
 	return FALSE;
 }
@@ -660,7 +654,7 @@ object_requested_cmd (GtkHTML *html, GtkHTMLEmbedded *eb, void *data)
 	if (eb->classid && strcmp (eb->classid, "mine:NULL") == 0)
 		return FALSE;
 
-	gtk_widget_ref (GTK_WIDGET (eb));
+	g_object_ref (eb);
 	g_timeout_add(rand() % 5000 + 1000, (GtkFunction) object_timeout, eb);
 	/* object_timeout (eb); */
 
@@ -668,7 +662,7 @@ object_requested_cmd (GtkHTML *html, GtkHTMLEmbedded *eb, void *data)
 }
 
 static void
-got_data (SoupMessage *msg, gpointer user_data)
+got_data (SoupSession *session, SoupMessage *msg, gpointer user_data)
 {
 	GtkHTMLStream *handle = user_data;
 
@@ -678,7 +672,8 @@ got_data (SoupMessage *msg, gpointer user_data)
 		return;
 	}
 
-	gtk_html_write (html, handle, msg->response.body, msg->response.length);
+	gtk_html_write (html, handle, msg->response_body->data,
+			msg->response_body->length);
 	gtk_html_end (html, handle, GTK_HTML_STREAM_OK);
 }
 
@@ -691,17 +686,8 @@ url_requested (GtkHTML *html, const char *url, GtkHTMLStream *handle, gpointer d
 
 	if (full_url && !strncmp (full_url, "http", 4)) {
 		SoupMessage *msg;
-#ifdef HAVE_OLD_SOUP
-		SoupContext *ctx;
-
-		ctx = soup_context_get (full_url);
-		msg = soup_message_new (ctx, SOUP_METHOD_GET);
-
-		soup_message_queue (msg, got_data, handle);
-#else
 		msg = soup_message_new (SOUP_METHOD_GET, full_url);
 		soup_session_queue_message (session, msg, got_data, handle);
-#endif
 	} else if (full_url && !strncmp (full_url, "file:", 5)) {
 		char *filename = gtk_html_filename_from_uri (full_url);
 		struct stat st;
@@ -852,11 +838,7 @@ goto_url(const char *url, int back_or_forward)
 	gchar *full_url;
 
 	/* Kill all requests */
-#ifdef HAVE_OLD_SOUP
-	soup_shutdown ();
-#else
 	soup_session_abort (session);
-#endif
 
 	/* Remove any pending redirection */
 	if(redirect_timerId) {
@@ -1042,8 +1024,6 @@ main (gint argc, gchar *argv[])
 
 	g_signal_connect (app, "delete_event", G_CALLBACK (exit_cb), NULL);
 
-	tooltips = gtk_tooltips_new ();
-
 	create_toolbars (app);
 	bar = gnome_appbar_new (FALSE, TRUE, GNOME_PREFERENCES_USER);
 	gnome_app_set_statusbar (GNOME_APP (app), bar);
@@ -1063,9 +1043,7 @@ main (gint argc, gchar *argv[])
 
 	gnome_app_set_contents (GNOME_APP (app), scrolled_window);
 
-#ifndef HAVE_OLD_SOUP
 	session = soup_session_async_new ();
-#endif
 
 	html_widget = gtk_html_new ();
 	html = GTK_HTML (html_widget);
@@ -1132,7 +1110,7 @@ main (gint argc, gchar *argv[])
 
 #ifdef MEMDEBUG
 
-	/* gtk_widget_unref (html_widget); */
+	/* g_object_unref (html_widget); */
 	free (p);
 #endif
 
